Welcome to the piecash documentation!
=====================================

:Release: |version|
:Date: |today|
:Authors: sdementen

.. toctree::
   :maxdepth: 1

   news.rst

Contents:

.. toctree::
   :maxdepth: 2

   doc/doc.rst
   tutorial/index.rst
   tutorial/examples.rst

For developers
==============

The complete api documentation:

.. toctree::
   :maxdepth: 4

   api/piecash.rst

with an overall view on the core objects in GnuCash:

.. toctree::
   :maxdepth: 2

   object_model.rst

The todo list:

- write more tests
- review non core objects (model_budget, model_business)

Indices and tables
==================

   * :ref:`genindex`
   * :ref:`modindex`
   * :ref:`search`
